summaryrefslogtreecommitdiff
path: root/sw/source/core/unocore/unoframe.cxx
diff options
context:
space:
mode:
authorLuboš Luňák <l.lunak@suse.cz>2012-10-12 16:49:40 +0200
committerLuboš Luňák <l.lunak@suse.cz>2012-10-12 16:56:54 +0200
commit21d10c6f3266d4fac9c91f9d0fab529a6841b39e (patch)
treed4436c5d48e16d81518906f5337bd16ae1dec823 /sw/source/core/unocore/unoframe.cxx
parent908794d36f489c60835bfa8a17ac6bd9c256c7df (diff)
mark lcl_ functions static or rename them if they are not local at all
http://lists.freedesktop.org/archives/libreoffice/2012-October/039639.html Change-Id: I21e12d6a4dfb9697d2346a4e564e96af0ad03f96
Diffstat (limited to 'sw/source/core/unocore/unoframe.cxx')
-rw-r--r--sw/source/core/unocore/unoframe.cxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/sw/source/core/unocore/unoframe.cxx b/sw/source/core/unocore/unoframe.cxx
index fe3ead635c89..a3d2fe28ee08 100644
--- a/sw/source/core/unocore/unoframe.cxx
+++ b/sw/source/core/unocore/unoframe.cxx
@@ -118,7 +118,7 @@
#include <comphelper/servicehelper.hxx>
// from fefly1.cxx
-extern sal_Bool lcl_ChkAndSetNewAnchor( const SwFlyFrm& rFly, SfxItemSet& rSet );
+extern sal_Bool sw_ChkAndSetNewAnchor( const SwFlyFrm& rFly, SfxItemSet& rSet );
using namespace ::com::sun::star;
using ::rtl::OUString;
@@ -533,7 +533,7 @@ SwFrameProperties_Impl::SwFrameProperties_Impl():
{
}
-inline void lcl_FillCol ( SfxItemSet &rToSet, const :: SfxItemSet &rFromSet, const :: uno::Any *pAny)
+static inline void lcl_FillCol ( SfxItemSet &rToSet, const :: SfxItemSet &rFromSet, const :: uno::Any *pAny)
{
if ( pAny )
{
@@ -600,7 +600,7 @@ SwGraphicProperties_Impl::SwGraphicProperties_Impl( ) :
{
}
-inline void lcl_FillMirror ( SfxItemSet &rToSet, const :: SfxItemSet &rFromSet, const ::uno::Any *pHEvenMirror, const ::uno::Any *pHOddMirror, const ::uno::Any *pVMirror, bool &rRet )
+static inline void lcl_FillMirror ( SfxItemSet &rToSet, const :: SfxItemSet &rFromSet, const ::uno::Any *pHEvenMirror, const ::uno::Any *pHOddMirror, const ::uno::Any *pVMirror, bool &rRet )
{
if(pHEvenMirror || pHOddMirror || pVMirror )
{
@@ -919,7 +919,7 @@ SdrObject *SwXFrame::GetOrCreateSdrObject( SwFlyFrmFmt *pFmt )
return pObject;
}
-SwFrmFmt *lcl_GetFrmFmt( const :: uno::Any& rValue, SwDoc *pDoc )
+static SwFrmFmt *lcl_GetFrmFmt( const :: uno::Any& rValue, SwDoc *pDoc )
{
SwFrmFmt *pRet = 0;
SwDocShell* pDocSh = pDoc->GetDocShell();
@@ -1068,7 +1068,7 @@ void SwXFrame::setPropertyValue(const :: OUString& rPropertyName, const :: uno::
SfxItemSet* pSet = 0;
// #i31771#, #i25798# - No adjustment of
// anchor ( no call of method <::lcl_ChkAndSetNewAnchor(..)> ),
// if document is currently in reading mode.
if ( !pFmt->GetDoc()->IsInReading() )
{
@@ -1086,7 +1086,7 @@ void SwXFrame::setPropertyValue(const :: OUString& rPropertyName, const :: uno::
{
pSet = new SfxItemSet( pDoc->GetAttrPool(), aFrmFmtSetRange );
pSet->Put( *pItem );
- if ( !::lcl_ChkAndSetNewAnchor( *pFly, *pSet ) )
+ if ( !sw_ChkAndSetNewAnchor( *pFly, *pSet ) )
delete pSet, pSet = 0;
}
}
@@ -1350,7 +1350,7 @@ void SwXFrame::setPropertyValue(const :: OUString& rPropertyName, const :: uno::
}
// #i31771#, #i25798# - No adjustment of
// anchor ( no call of method <::lcl_ChkAndSetNewAnchor(..)> ),
// if document is currently in reading mode.
if ( !pFmt->GetDoc()->IsInReading() )
{
@@ -1364,7 +1364,7 @@ void SwXFrame::setPropertyValue(const :: OUString& rPropertyName, const :: uno::
if( SFX_ITEM_SET == aSet.GetItemState( RES_ANCHOR, false, &pItem ))
{
aSet.Put( *pItem );
- ::lcl_ChkAndSetNewAnchor( *pFly, aSet );
+ sw_ChkAndSetNewAnchor( *pFly, aSet );
}
}
}
@@ -1068,7 +1068,7 @@ void SwXFrame::setPropertyValue(const :: OUString& rPropertyName, const :: uno::
SfxItemSet* pSet = 0;
// #i31771#, #i25798# - No adjustment of
- // anchor ( no call of method <::lcl_ChkAndSetNewAnchor(..)> ),
+ // anchor ( no call of method <sw_ChkAndSetNewAnchor(..)> ),
// if document is currently in reading mode.
if ( !pFmt->GetDoc()->IsInReading() )
@@ -1350,7 +1350,7 @@ void SwXFrame::setPropertyValue(const :: OUString& rPropertyName, const :: uno::
}
// #i31771#, #i25798# - No adjustment of
- // anchor ( no call of method <::lcl_ChkAndSetNewAnchor(..)> ),
+ // anchor ( no call of method <sw_ChkAndSetNewAnchor(..)> ),
// if document is currently in reading mode.
if ( !pFmt->GetDoc()->IsInReading() )